@@ -2,7 +2,12 @@ import ctypes
 import sys
 from importlib import resources
 
-from floc.go_types import ApplySortingLshResult, GoSlice, SimulateResult
+from floc.go_types import (
+    ApplySortingLshResult,
+    GoSlice,
+    SimHashStringResult,
+    SimulateResult,
+)
 
 floc_go_so = f'floc_go-{sys.platform}.so'
 with resources.path('floc.floc_go', floc_go_so) as floc_go_file:
@@ -19,11 +24,15 @@ FLOC_GO.cityHash64WithSeedsV103.restype = ctypes.c_uint64
 FLOC_GO.cityHash64WithSeedV103.argtypes = [ctypes.c_char_p, ctypes.c_uint64]
 FLOC_GO.cityHash64WithSeedV103.restype = ctypes.c_uint64
 
-FLOC_GO.simHashString.argtypes = [GoSlice]
-FLOC_GO.simHashString.restype = ctypes.c_uint64
+FLOC_GO.simHashString.argtypes = [GoSlice, ctypes.c_uint8]
+FLOC_GO.simHashString.restype = SimHashStringResult
 
-FLOC_GO.applySortingLsh.argtypes = [ctypes.c_uint64, ctypes.c_char_p]
+FLOC_GO.applySortingLsh.argtypes = [
+    ctypes.c_uint64, ctypes.c_char_p, ctypes.c_uint8, ctypes.c_bool,
+]
 FLOC_GO.applySortingLsh.restype = ApplySortingLshResult
 
-FLOC_GO.simulate.argtypes = [GoSlice, ctypes.c_char_p]
+FLOC_GO.simulate.argtypes = [
+    GoSlice, ctypes.c_char_p, ctypes.c_uint8, ctypes.c_bool,
+]
 FLOC_GO.simulate.restype = SimulateResult
